:py:mod:`pytomography.io.CT.dicom_ct_pd`
========================================

.. py:module:: pytomography.io.CT.dicom_ct_pd


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   pytomography.io.CT.dicom_ct_pd.get_geometry_info_from_datasets_gen3
   pytomography.io.CT.dicom_ct_pd.get_projections_and_metadata_gen3



.. py:function:: get_geometry_info_from_datasets_gen3(paths)


.. py:function:: get_projections_and_metadata_gen3(paths)


